==> file_cache-0.1.8.tar.gz: lib/src/file_cache_image.dart <==
import 'dart:async';
import 'dart:typed_data';

import 'package:flutter/painting.dart';
import 'package:flutter/foundation.dart';
// import 'dart:ui' as ui show instantiateImageCodec, Codec;
import 'dart:ui' as ui show Codec;

import 'file_cache.dart';

/// Creates an [ImageProvider] which loads an image from the [url], using the [scale].
/// [NetworkImage] with file cache.
@immutable
class FileCacheImage extends ImageProvider<FileCacheImage> {
  const FileCacheImage(
    this.url, {
    this.scale: 1.0,
  })  : assert(url != null),
        assert(scale != null);

  /// The URL from which the image will be fetched.
  final String url;

  /// The scale to place in the [ImageInfo] object of the image.
  final double scale;

  @override
  Future<FileCacheImage> obtainKey(ImageConfiguration configuration) {
    return SynchronousFuture<FileCacheImage>(this);
  }

  @override
  ImageStreamCompleter load(FileCacheImage key, DecoderCallback decode) {
    return MultiFrameImageStreamCompleter(
      codec: _loadAsync(key, decode),
      scale: key.scale,
    );
  }

  Future<ui.Codec> _loadAsync(
      FileCacheImage key, DecoderCallback decode) async {
    assert(key == this);
    FileCache fileCache = await FileCache.fromDefault();

    // try {
    //   final Uint8List bytes = await fileCache.getBytes(key.url);
    //   return await ui.instantiateImageCodec(bytes);
    // } catch (error) {
    //   return null;
    // }

    final Uint8List bytes = await fileCache.getBytes(key.url);
    if (bytes.lengthInBytes == 0) {
      // The file may become available later.
      PaintingBinding.instance.imageCache.evict(key);
      throw StateError('$url is empty and cannot be loaded as an image.');
    }

    return decode(bytes);
  }

  @override
  bool operator ==(Object other) {
    if (other.runtimeType != runtimeType) return false;

    return other is FileCacheImage && url == other.url && scale == other.scale;
  }

  @override
  int get hashCode => hashValues(url, scale);

  @override
  String toString() =>
      '${objectRuntimeType(this, 'FileCacheImage')}("$url", scale: $scale)';
}

==> file_cache-0.2.0.tar.gz: lib/src/file_cache_image.dart <==
import 'dart:async';
import 'dart:typed_data';

import 'package:flutter/painting.dart';
import 'package:flutter/foundation.dart';
import 'dart:ui' as ui show instantiateImageCodec, Codec;

import 'file_cache.dart';

class FileCacheImage extends ImageProvider<FileCacheImage> {
  /// Creates an ImageProvider which loads an image from the [url], using the [scale].
  const FileCacheImage(
    this.url, {
    this.scale: 1.0,
  });

  /// The URL from which the image will be fetched.
  final String url;

  /// The scale to place in the [ImageInfo] object of the image.
  final double scale;

  @override
  Future<FileCacheImage> obtainKey(ImageConfiguration configuration) {
    return SynchronousFuture<FileCacheImage>(this);
  }

  @override
  ImageStreamCompleter load(FileCacheImage key, DecoderCallback decode) {
    return MultiFrameImageStreamCompleter(
      codec: _loadAsync(key),
      scale: key.scale,
    );
  }

  Future<ui.Codec> _loadAsync(FileCacheImage key) async {
    assert(key == this);
    FileCache fileCache = await FileCache.fromDefault();
    final Uint8List bytes = await fileCache.getBytes(key.url);

    return await ui.instantiateImageCodec(bytes);
  }

  @override
  bool operator ==(dynamic other) {
    if (other.runtimeType != runtimeType) return false;
    final FileCacheImage typedOther = other;
    return url == typedOther.url && scale == typedOther.scale;
  }

  @override
  int get hashCode => hashValues(url, scale);

  @override
  String toString() => '$runtimeType("$url", scale: $scale)';
}
